
; ==============================================================================================
;
; --------------------------------------------------
; TARGET
; --------------------------------------------------
;
; This is 32 KB sized code to go into ROM U18 (which is 32 KB sized) on an IBM 5160 (IBM XT) motherboard.
;
; If your IBM 5160 motherboard is a 64-256KB type, the TMM23256/MK37000/MK38000 ROM's can in most cases be replaced with 27C256 EPROM's,
; but some brands of 27C256 may be unsuitable for the 64-256KB motherboard - see http://www.minuszerodegrees.net/5160/motherboard/5160_u18_u19_sockets.htm
;    
; If your IBM 5160 motherboard is a 256-640KB type, then you can use a 27C256 (or 27256) EPROM, or a Winbond W27E257.
;      
; For the IBM 5160, use EPROM's that are rated at 250 ns, or faster.
; See http://www.minuszerodegrees.net/5160/motherboard/IBM%205160%20motherboard%20-%20ROM%20description%20from%20TR.png
;
;
; --------------------------------------------------
; REQUIRED
; --------------------------------------------------
;
; 1. A way of putting TEST6066_32KB_SIZED.BIN into a suitable ROM/EPROM/EEPROM.
;
; 2. Logic analyser (and the knowledge of how to use it).
;
;
; --------------------------------------------------
; WHAT DOES THE CODE DO ?
; --------------------------------------------------
;
; In a loop, the code:
; Step 1: Reads address 55555 hex  (5555:0005) (01010101010101010101 binary)
; Step 2: Reads address AAAAA hex  (AAAA:000A) (10101010101010101010 binary)
;
; 55555 and AAAAA chosen because they will reveal if any adjacent bits are 'shorted'.
;
; An example of adjacent bits is A0 and A1.
; An example of adjacent bits is A1 and A2.
; An example of adjacent bits is A2 and A3.
;
;
; --------------------------------------------------
; WHAT YOU SHOULD OBSERVE IF USING A LOGIC ANALYSER
; --------------------------------------------------
;
; Reference diagram at https://minuszerodegrees.net/5160/misc/5160_address_bus.jpg
;
; Using a logic analyser:
; 1. On the address bus, verify that two of the addresses seen are 55555 and AAAAA, i.e. all adjacent bits are at different logic states.
; 2. On the external address bus, verify that two of the addresses seen are 55555 and AAAAA, i.e. all adjacent bits are at different logic states.
;
;
; --------------------------------------------------
; WHAT YOU SHOULD OBSERVE IF USING AN OSCILLOSCOPE
; --------------------------------------------------
;
; Reference diagram at https://minuszerodegrees.net/5160/misc/5160_address_bus.jpg
;
; Using an oscilloscope:
; Verify that adjacent bits are at different logic states.
;
; E.g. When you see A4 at HIGH, A3 and A5 should be LOW.
;
;  
; -------------------------------------------------------
; LIMITATIONS
; -------------------------------------------------------
; 
; Certain cases of motherboard failure will stop this code from running.

; -------------------------------------------------------
; COMPILATION
; -------------------------------------------------------
; 
; COMPILE THIS CODE USING NASM 2.10 (OR LATER).
;
; ==============================================================================================

BITS 16

CPU 8086

ORG 0			; Offset 0 in ROM (i.e. address F8000 in IBM 5160 address space)

TIMES 0x7F00-($-$$) DB 0	; Pad with zero to address 7F00h in 32 KB sized ROM (i.e. address FFF00 in IBM 5160 address space)

; ----------------------------------------------------------------------------------------------
; CODE STARTS HERE, AT ADDRESS 7F00h in ROM (i.e. address FFF00 in IBM 5160 address space)
; ----------------------------------------------------------------------------------------------

	cli

LOOP:	mov	dx,5555h
	mov	es,dx
	mov	al,byte es:[5]		; Read address 55555h (5555:0005 in the CPU)

	mov	dx,0AAAAh
	mov	es,dx
	mov	al,byte es:[0Ah]	; Read address AAAAAh (AAAA:000A in the CPU)

	jmp	LOOP


TIMES 0x7FF0-($-$$) DB 0	; Pad out to reset vector in 32 KB sized ROM
	jmp	0xFF00:0000

TIMES 0x8000-($-$$) DB 0	; Pad out to end of 32 KB sized ROM 





